@@ -1,6 +1,7 @@
 import glob
 import os
 import csv
+import re
 import shutil
 import tarfile
 import urllib.request, urllib.error, urllib.parse
@@ -689,6 +690,36 @@ class IdenticalChains(PDBeSolrSearch):
                 break
 
 
+class IdenticalChainsAndEntityId(PDBeSolrSearch):
+    '''
+       Find identical chains to a given one
+
+       example:
+       a = IdenticalChainsAndEntityId("2jlo",chain="A").get()
+
+       Parameters
+       ==========
+       pdbcode: string - PDB ID
+
+       Returns
+       ==========
+       (entity_id, [chains])
+    '''
+
+    def __init__(self, pdbcode, chain):
+        super().__init__()
+
+        self.results = (None, None)
+        documents = self.exec_query("pdb_id,entity_id,chain_id,assembly_composition", [('pdb_id', pdbcode)])
+
+        for i in range(len(documents)):
+            chain_id = documents[i]['chain_id']
+            ent_id = documents[i]['entity_id']
+            if chain in chain_id:
+                self.results = (ent_id, sorted(chain_id))
+                break
+
+
 class SimilarChains(PDBeSolrSearch):
     '''
        Find similar chains to a given one with sequence identity given as parameter
@@ -918,3 +949,29 @@ class UniprotInfo():
             for line in data.split('\n'):
                 seq += line if not line.startswith('>') else ''
         return seq
+
+    def get_title(self):
+        url_from = 'https://www.uniprot.org/uniprot/{}.txt'.format(self.uniid)
+        title = None
+        with urllib.request.urlopen(url_from) as url:
+            data = url.read().decode()
+            for line in data.split('\n'):
+                if line.startswith('DE') and line.find('Full=')>0:
+                    title = line.split('=')[1][:-1]
+                    return re.sub(r'{([^}]*)}', '', title).strip()
+        return title
+
+    def get_pdbs(self):
+        url_from = 'https://www.uniprot.org/uniprot/{}.txt'.format(self.uniid)
+        pdbs = []
+        with urllib.request.urlopen(url_from) as url:
+            data = url.read().decode()
+            for line in data.split('\n'):
+                if line.startswith('DR') and line.find('PDB;')>0:
+                    els = line.split(';')
+                    pdbcode = els[1].strip()
+                    chains, pos = els[4].strip().split('=')
+                    chains = chains.replace('/',',')
+                    pos = pos.replace('.','')
+                    pdbs.append((pdbcode, chains, pos))
+        return pdbs
